@@ -16,7 +16,7 @@
 #' @template section_dictionary_learner
 #'
 #' @references
-#' `r tools::toRd(bibentries["venables_2002"])`
+#' `r format_bib("venables_2002")`
 #'
 #' @export
 #' @template seealso_learner
@@ -74,7 +74,7 @@ LearnerClassifLDA = R6Class("LearnerClassifLDA",
         pars$predict.prior = NULL
       }
       newdata = task$data(cols = task$feature_names)
-      p = mlr3misc::invoke(stats::predict, self$model,
+      p = mlr3misc::invoke(predict, self$model,
         newdata = newdata,
         .args = self$param_set$get_values(tags = "predict"))
 
