@@ -8,14 +8,18 @@
 #'
 #' @section Custom mlr3 defaults:
 #' - `nrounds`:
-#'   - Actual default: no default
-#'   - Adjusted default: 1
+#'   - Actual default: no default.
+#'   - Adjusted default: 1.
 #'   - Reason for change: Without a default construction of the learner
 #'     would error. Just setting a nonsense default to workaround this.
 #'     `nrounds` needs to be tuned by the user.
+#' - `nthread`:
+#'   - Actual value: Undefined, triggering auto-detection of the number of CPUs.
+#'   - Adjusted value: 1.
+#'   - Reason for change: Conflicting with parallelization via \CRANpkg{future}.
 #' - `verbose`:
-#'   - Actual default: 1
-#'   - Adjusted default: 0
+#'   - Actual default: 1.
+#'   - Adjusted default: 0.
 #'   - Reason for change: Reduce verbosity.
 #'
 #' @template section_dictionary_learner
@@ -68,7 +72,7 @@ LearnerClassifXgboost = R6Class("LearnerClassifXgboost",
           default = 0L, lower = -1L, upper = 1L,
           tags = c("train", "control")),
         ParamDbl$new("tweedie_variance_power", lower = 1, upper = 2, default = 1.5, tags = "train"),
-        ParamInt$new("nthread", lower = 1L, tags = c("train", "control")),
+        ParamInt$new("nthread", lower = 1L, default = 1L, tags = c("train", "control", "threads")),
         ParamInt$new("nrounds", default = 1, lower = 1L, tags = c("train")),
         ParamUty$new("feval", default = NULL, tags = "train"),
         ParamInt$new("verbose", default = 1L, lower = 0L, upper = 2L, tags = "train"),
@@ -141,7 +145,7 @@ LearnerClassifXgboost = R6Class("LearnerClassifXgboost",
       ps$add_dep("top_k", "feature_selector", CondAnyOf$new(c("greedy", "thrifty")))
 
       # custom defaults
-      ps$values = list(verbose = 0L, nrounds = 1)
+      ps$values = list(nrounds = 1L, nthread = 1L, verbose = 0L)
 
       super$initialize(
         id = "classif.xgboost",
