@@ -37,9 +37,6 @@ LearnerRegrGlmnet = R6Class("LearnerRegrGlmnet",
           tags = "train"),
         ParamUty$new("offset", default = NULL, tags = "train"),
         ParamDbl$new("alpha", default = 1, lower = 0, upper = 1, tags = "train"),
-        ParamFct$new("type.measure",
-          levels = c("deviance", "class", "auc", "mse", "mae"),
-          default = "deviance", tags = "train"),
         ParamDbl$new("s", lower = 0, default = 0.01, tags = "predict"),
         ParamInt$new("nlambda", default = 100L, lower = 1L, tags = "train"),
         ParamDbl$new("lambda.min.ratio", lower = 0, upper = 1, tags = "train"),
